==> haskell-warp-3.2.27-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp
version: 3.2.27
id: warp-3.2.27-Cf1ZHJJJQZQIKp37PcGy6p
key: warp-3.2.27-Cf1ZHJJJQZQIKp37PcGy6p
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, Kazu Yamamoto, Matt Brown
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.
category: Web, Yesod
abi: ab263c1a2ffa76cf6256d662c1c5ac53
exposed: True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal
hidden-modules: Network.Wai.Handler.Warp.Buffer
                Network.Wai.Handler.Warp.Conduit Network.Wai.Handler.Warp.Counter
                Network.Wai.Handler.Warp.Date Network.Wai.Handler.Warp.FdCache
                Network.Wai.Handler.Warp.File
                Network.Wai.Handler.Warp.FileInfoCache
                Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                Network.Wai.Handler.Warp.HTTP2.EncodeFrame
                Network.Wai.Handler.Warp.HTTP2.File
                Network.Wai.Handler.Warp.HTTP2.HPACK
                Network.Wai.Handler.Warp.HTTP2.Manager
                Network.Wai.Handler.Warp.HTTP2.Receiver
                Network.Wai.Handler.Warp.HTTP2.Request
                Network.Wai.Handler.Warp.HTTP2.Sender
                Network.Wai.Handler.Warp.HTTP2.Types
                Network.Wai.Handler.Warp.HTTP2.Worker
                Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
                Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
                Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
                Network.Wai.Handler.Warp.Request
                Network.Wai.Handler.Warp.RequestHeader
                Network.Wai.Handler.Warp.Response
                Network.Wai.Handler.Warp.ResponseHeader
                Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
                Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Timeout
                Network.Wai.Handler.Warp.Types Network.Wai.Handler.Warp.Windows
                Network.Wai.Handler.Warp.WithApplication Paths_warp
                Network.Wai.Handler.Warp.MultiMap
import-dirs: /usr/lib/ghc-8.6.5/site-local/warp-3.2.27
library-dirs: /usr/lib/ghc-8.6.5/site-local/warp-3.2.27
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/warp-3.2.27
hs-libraries: HSwarp-3.2.27-Cf1ZHJJJQZQIKp37PcGy6p
depends:
    array-0.5.3.0 async-2.2.1-GYH0rb5jjEHH7NChV9fWYh
    auto-update-0.1.4.1-H02SxzDXmGPGYG55qTZ7dl base-4.12.0.0
    bsb-http-chunked-0.0.0.4-5BqxJpsQbLzEWyrRm2uZJ5 bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk containers-0.6.0.1
    ghc-prim-0.5.3 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-date-0.0.8-2aJEXtltdzABpfWDz8Xhol
    http-types-0.12.3-KTFxmt6v4566xpn9x45HFw
    http2-1.6.5-54Vra6CX3sG1890AaB3OUt
    iproute-1.7.7-FRlXPwxid8JMOv62fp4zU
    network-2.8.0.0-A0G1UJzDIGiEvzFah0DnI2
    simple-sendfile-0.2.28-2uZdhQSfL5h4JSNgB9fHya stm-2.5.0.0
    streaming-commons-0.2.1.0-HgshHrAW4sJ7tnvtY46l5k text-1.2.3.1
    unix-2.7.2.2 unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    vault-0.3.1.2-DLWTZx3oQ7cL42xpQaTK7X
    wai-3.2.2-GlQJpLVznLECwkQpTtQzT9 word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html: /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-3.2.27-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp
version: 3.2.27
id: warp-3.2.27-JdQvbkIqbZY467KZU6Vbf5
key: warp-3.2.27-JdQvbkIqbZY467KZU6Vbf5
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, Kazu Yamamoto, Matt Brown
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.
category: Web, Yesod
abi: bb5fba7c797563a54b782da4d5685b43
exposed: True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal
hidden-modules: Network.Wai.Handler.Warp.Buffer
                Network.Wai.Handler.Warp.Conduit Network.Wai.Handler.Warp.Counter
                Network.Wai.Handler.Warp.Date Network.Wai.Handler.Warp.FdCache
                Network.Wai.Handler.Warp.File
                Network.Wai.Handler.Warp.FileInfoCache
                Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                Network.Wai.Handler.Warp.HTTP2.EncodeFrame
                Network.Wai.Handler.Warp.HTTP2.File
                Network.Wai.Handler.Warp.HTTP2.HPACK
                Network.Wai.Handler.Warp.HTTP2.Manager
                Network.Wai.Handler.Warp.HTTP2.Receiver
                Network.Wai.Handler.Warp.HTTP2.Request
                Network.Wai.Handler.Warp.HTTP2.Sender
                Network.Wai.Handler.Warp.HTTP2.Types
                Network.Wai.Handler.Warp.HTTP2.Worker
                Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
                Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
                Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
                Network.Wai.Handler.Warp.Request
                Network.Wai.Handler.Warp.RequestHeader
                Network.Wai.Handler.Warp.Response
                Network.Wai.Handler.Warp.ResponseHeader
                Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
                Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Timeout
                Network.Wai.Handler.Warp.Types Network.Wai.Handler.Warp.Windows
                Network.Wai.Handler.Warp.WithApplication Paths_warp
                Network.Wai.Handler.Warp.MultiMap
import-dirs: /usr/lib/ghc-8.6.5/site-local/warp-3.2.27
library-dirs: /usr/lib/ghc-8.6.5/site-local/warp-3.2.27
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/warp-3.2.27
hs-libraries: HSwarp-3.2.27-JdQvbkIqbZY467KZU6Vbf5
depends:
    array-0.5.3.0 async-2.2.1-GYH0rb5jjEHH7NChV9fWYh
    auto-update-0.1.4.1-H02SxzDXmGPGYG55qTZ7dl base-4.12.0.0
    bsb-http-chunked-0.0.0.4-2fyQDC2VyDkLsvBIeKp2Es bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk containers-0.6.0.1
    ghc-prim-0.5.3 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-date-0.0.8-23DIlkWU7Vf6oH2Lmm4SUG
    http-types-0.12.3-KTFxmt6v4566xpn9x45HFw
    http2-1.6.5-JOixQd1QsRD25hmaMocRkJ
    iproute-1.7.7-FRlXPwxid8JMOv62fp4zU
    network-2.8.0.0-A0G1UJzDIGiEvzFah0DnI2
    simple-sendfile-0.2.28-2jBEu40P91F3SXyDycEM4A stm-2.5.0.0
    streaming-commons-0.2.1.0-HgshHrAW4sJ7tnvtY46l5k text-1.2.3.1
    unix-2.7.2.2 unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    vault-0.3.1.2-DLWTZx3oQ7cL42xpQaTK7X
    wai-3.2.2-GlQJpLVznLECwkQpTtQzT9 word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html: /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
